@@ -51,7 +51,7 @@ void SystemsettingsRunner::match(Plasma::RunnerContext &context)
         QMutexLocker lock(&m_mutex);
         if (m_modules.isEmpty()) {
             KSycoca::disableAutoRebuild();
-            m_modules = findKCMsMetaData(MetaDataSource::All);
+            m_modules = findKCMsMetaData(MetaDataSource::All, false);
         }
     }
     matchNameKeywordAndGenericName(context);
@@ -153,8 +153,21 @@ void SystemsettingsRunner::matchNameKeywordAndGenericName(Plasma::RunnerContext
                 relevance += 0.1;
             }
         } else {
+            // check if the generic name or description matches
             if (!checkMatchAndRelevance(data.value(QStringLiteral("GenericName")), 0.65) && !checkMatchAndRelevance(data.description(), 0.5)) {
-                continue;
+                // if not, check the keyowords
+                const QString &query = ctx.query();
+                const QStringList keywords = data.value(QStringLiteral("X-KDE-Keywords")).split(QLatin1Char(','));
+                bool anyKeywordMatches = std::any_of(keywords.begin(), keywords.end(), [&query](const QString &keyword) {
+                    return keyword.startsWith(query);
+                });
+                if (anyKeywordMatches && keywords.contains(query, Qt::CaseInsensitive)) {
+                    relevance = 0.5; // If the keyword matches exactly we give it the same relevance as if the description matched
+                } else if (anyKeywordMatches) {
+                    relevance = 0.2; // give it a lower relevance than if it had been found by name or description
+                } else {
+                    continue; // we haven't found any matching keyword, skip this KCM
+                }
             }
         }
 
